/**
 * Combined execution state of an `RxCommand`
 * Will be issued for any state change of any of the fields
 * During normal command execution you will get this items listening at the command's [.results] observable.
 * 1. If the command was just newly created you will get `null, null, false` (data, error, isExecuting)
 * 2. When calling execute: `null, null, true`
 * 3. When execution finishes: `the result, null, false`
 * 3. When execution finishes: `param data, the result, null, false`
 *`param data` is the data that you pass as parameter when calling the command
 */
declare class CommandResult<TParam = void, TResult = void> {
    readonly param: TParam | undefined;
    readonly data: TResult | undefined;
    readonly error: Error | undefined;
    readonly isExecuting: boolean;
    constructor(param: TParam | undefined, data: TResult | undefined, error: Error | undefined, isExecuting: boolean);
    static data<TParam = void, TResult = void>(param: TParam | undefined, result: TResult): CommandResult<TParam, TResult>;
    static error<TParam = void, TResult = void>(param: TParam | undefined, error: Error): CommandResult<TParam, TResult>;
    static loading<TParam = void, TResult = void>(param?: TParam): CommandResult<TParam, TResult>;
    static blank<TParam = void, TResult = void>(): CommandResult<TParam, TResult>;
    get hasData(): boolean;
    get hasError(): boolean;
    equals(other: CommandResult<TParam, TResult>): boolean;
    toString(): string;
}

export { CommandResult };
