import './types.js';
import { RxCommand } from './rx_commands.js';
import './command_error.js';
import './command_result.js';
import { Subscription } from 'rxjs';

/**
 * [RxListener] can be used to hold subscriptions to [RxCommand]s and Observables.
 * When a [RxListener] is disposed all subscriptions will be unsubscribed
 *
 * When a [RxCommand] subscription is added, [RxListener] will automatically subscribe to command `thrownExceptions` observable and will log errors to the `console.error`. This behavior is configurable.
 */
declare class RxListener {
    private _listners;
    private _commands;
    /**
     * Global handle to enable/disable logging of [RxCommand] errors
     */
    static listenToCommandExceptions: boolean;
    set sink(reference: Subscription | RxCommand<any, any>);
    add(references: (Subscription | RxCommand<any, any>)[]): void;
    dispose(): void;
    private _listenToCommandExceptions;
}

export { RxListener };
