import { match, P } from "ts-pattern";
import { filter, Subscription } from "rxjs";
import { RxCommand } from "./rx_commands.js";
class RxListener {
  _listners = new Subscription();
  _commands = [];
  /**
   * Global handle to enable/disable logging of [RxCommand] errors
   */
  static listenToCommandExceptions = true;
  set sink(reference) {
    this.add([reference]);
  }
  add(references) {
    for (const reference of references) {
      match(reference).with(
        P.instanceOf(Subscription),
        (subscription) => this._listners.add(subscription)
      ).with(P.instanceOf(RxCommand), (command) => {
        const subscription = this._listenToCommandExceptions(command);
        this._commands.push(command);
        this._listners.add(subscription);
      });
    }
  }
  dispose() {
    this._listners.unsubscribe();
    for (const command of this._commands) {
      command.dispose();
    }
    this._listners = new Subscription();
    this._commands = [];
  }
  _listenToCommandExceptions(command) {
    return command.thrownExceptions.pipe(filter(() => RxListener.listenToCommandExceptions)).subscribe((error) => console.error(error));
  }
}
export {
  RxListener
};
