import { Observable } from 'rxjs';

type Action<TParam = void, TResult = void> = (param: TParam) => TResult;
type AsyncAction<TParam = void, TResult = void> = (param: TParam) => Promise<TResult>;
type ObservableAction<TParam = void, TResult = void> = (param: TParam) => Observable<TResult>;
/**
 * if you want to get an initial Result with `data==null, error==null, isExecuting==false` pass
 * [emitInitialCommandResult=true].
 * [emitLastResult] will include the value of the last successful execution in all [CommandResult] events unless there is no result.
 * By default the [results] Observable and the [RxCommand] itself behave like a Subject. If you want that it acts like
 * a BehaviourSubject, meaning every listener gets the last received value, you can set [emitsLastValueToNewSubscriptions = true].
 * [initialLastResult] sets the value of the [lastResult] property before the first item was received.
 * [debugName] optional identifier that is included when you register a [globalExceptionHandler]
 * or a [loggingHandler]
 */
interface RxCommandOptions<TResult = void> {
    restriction?: Observable<boolean>;
    emitInitialCommandResult?: boolean;
    emitLastResult?: boolean;
    emitsLastValueToNewSubscriptions?: boolean;
    initialLastResult?: TResult;
    debugName?: string;
}
declare function nameOf(func: () => unknown): string;

export { type Action, type AsyncAction, type ObservableAction, type RxCommandOptions, nameOf };
